
# Google Sheet MCP Server

An MCP Server for the Google Sheet API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Google Sheet API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| create_spreadsheet | Creates a new blank Google Spreadsheet with the specified title. |
| get_spreadsheet | Returns the spreadsheet details. |
| batch_get_values | Returns one or more ranges of values from a spreadsheet. |
| clear_values | Clears values from a spreadsheet. Only values are cleared -- all other properties 
of the cell (such as formatting, data validation, etc.) are kept. |
| update_values | Sets values in a range of a spreadsheet. |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Google Sheet app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
